@@ -571,7 +571,7 @@ eh_config_vhost_prepare (eh_config_vhost_t *vhost, const char *hostname,
   if (eh_config_path_apply_chroot (&vhost->documentroot_fullpath, ecg)) {
     x_append_printf (&ecg->error_string,
 		     "document root '%s' is not a subdirectory of "
-		     "chrooted root '%s'",
+		     "ChangeRoot directory '%s'\n",
 		     vhost->documentroot_fullpath, ecg->change_root_fullpath);
     ecg->fatal_error = 1;
   }
@@ -589,7 +589,7 @@ eh_config_vhost_prepare (eh_config_vhost_t *vhost, const char *hostname,
       if (eh_config_path_apply_chroot (&entarr[i].dirname, ecg)) {
 	x_append_printf (&ecg->error_string,
 			 "<Directory \"%s\"> is not a subdirectory of "
-			 "chrooted root '%s'",
+			 "ChangeRoot directory '%s'\n",
 			 entarr[i].dirname, ecg->change_root_fullpath);
 	ecg->fatal_error = 1;
       }
@@ -617,7 +617,7 @@ eh_config_vhost_prepare (eh_config_vhost_t *vhost, const char *hostname,
       if (eh_config_path_apply_chroot (&vhost->alias_arr[i].dest, ecg)) {
 	x_append_printf (&ecg->error_string,
 			 "Alias destination '%s' is not a subdirectory of "
-			 "chrooted root '%s'",
+			 "ChangeRoot directory '%s'\n",
 			 vhost->alias_arr[i].dest, ecg->change_root_fullpath);
 	ecg->fatal_error = 1;
       }
@@ -638,7 +638,7 @@ eh_config_vhost_prepare (eh_config_vhost_t *vhost, const char *hostname,
 				&nofilesystem);
       if (rhfunc == NULL) {
 	x_append_printf (&ecg->error_string,
-			 "Request Handler '%s' not found", ent->rhfunc_name);
+			 "Request Handler '%s' not found\n", ent->rhfunc_name);
 	ecg->fatal_error = 1;
       } else {
 	ent->rhfunc = rhfunc;
